# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.19.2~0f04694',
    built_at='2025-07-23 08:03:59Z',
    sha='0f04694d6c840b8c41fadcf574173e50313464af',
    branch='HEAD',
    tag='v4.19.2',
)
